summaryrefslogtreecommitdiff
path: root/sys/dev/dm/dm_target_linear.c
diff options
context:
space:
mode:
authortkusumi <tkusumi@NetBSD.org>2019-12-15 05:56:02 +0000
committertkusumi <tkusumi@NetBSD.org>2019-12-15 05:56:02 +0000
commit23ef6e5dd08de606f940a71b427520d20082fd32 (patch)
tree04510307f6d0dd42d4239532b4bae0a4f0d47507 /sys/dev/dm/dm_target_linear.c
parentee241c51f0f2fba701d900b361985399bda33631 (diff)
dm: Rename targets' ->status() to ->table() given ->info() exists
Since now that dm targets in NetBSD have ->info() for "status", ->status() should be renamed to ->table() for "table", given how dm target status was originally designed in Linux kernel. taken-from: DragonFlyBSD
Diffstat (limited to 'sys/dev/dm/dm_target_linear.c')
-rw-r--r--sys/dev/dm/dm_target_linear.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sys/dev/dm/dm_target_linear.c b/sys/dev/dm/dm_target_linear.c
index 235c9cee5c4..0cc4113c3d7 100644
--- a/sys/dev/dm/dm_target_linear.c
+++ b/sys/dev/dm/dm_target_linear.c
@@ -1,4 +1,4 @@
-/* $NetBSD: dm_target_linear.c,v 1.28 2019/12/14 10:02:35 tkusumi Exp $ */
+/* $NetBSD: dm_target_linear.c,v 1.29 2019/12/15 05:56:02 tkusumi Exp $ */
/*
* Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
* POSSIBILITY OF SUCH DAMAGE.
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: dm_target_linear.c,v 1.28 2019/12/14 10:02:35 tkusumi Exp $");
+__KERNEL_RCSID(0, "$NetBSD: dm_target_linear.c,v 1.29 2019/12/15 05:56:02 tkusumi Exp $");
/*
* This file implements initial version of device-mapper dklinear target.
@@ -84,18 +84,18 @@ dm_target_linear_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
* Status routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.
*/
char *
-dm_target_linear_status(void *target_config)
+dm_target_linear_table(void *target_config)
{
dm_target_linear_config_t *tlc;
char *params;
tlc = target_config;
- aprint_debug("Linear target status function called\n");
+ aprint_debug("Linear target table function called\n");
params = kmem_alloc(DM_MAX_PARAMS_SIZE, KM_SLEEP);
snprintf(params, DM_MAX_PARAMS_SIZE, "%s %" PRIu64,
@@ -84,18 +84,18 @@ dm_target_linear_init(dm_table_entry_t *table_en, int argc, char **argv)
}
/*
- * Status routine is called to get params string, which is target
+ * Table routine is called to get params string, which is target
* specific. When dm_table_status_ioctl is called with flag
* DM_STATUS_TABLE_FLAG I have to sent params string back.